import { Component, inject, OnDestroy } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Subscription } from 'rxjs';
import { KeyListComponent } from '../key-list/key-list.component';
import ApiKey from '../../shared/models/api-key';
import EventService from '../../shared/services/EventService';
import { ApiKeyService } from '../../shared/services/api/api-key.service';

@Component({
  selector: 'keys',
  imports: [KeyListComponent],
  templateUrl: './keys.component.html',
  styleUrl: './keys.component.scss'
})
export class KeysComponent implements OnDestroy {
  private readonly route = inject(ActivatedRoute);
  private readonly events = inject(EventService);
  private readonly keyService = inject(ApiKeyService);

  subscriptions: (Subscription | undefined)[] = [];
  keys: ApiKey[] = [];


  constructor() {
    this.route.data.subscribe(payload => {
      this.keys = payload['keys'] ?? [];
    });

    this.subscriptions.push(this.events.listen('add_api_key', _ => this.keyService.fetch().subscribe(keys => this.keys = keys)));
    this.subscriptions.push(this.events.listen('delete_api_key', _ => this.keyService.fetch().subscribe(keys => this.keys = keys)));
  }

  ngOnDestroy(): void {
    for (let subscription of this.subscriptions) {
      if (subscription)
        subscription.unsubscribe();
    }
  }
}
