import { Component, inject, input, OnDestroy, OnInit, ViewChild } from '@angular/core';
import { MatTable, MatTableModule } from '@angular/material/table';
import { MatIconModule } from '@angular/material/icon';
import { Policy } from '../../shared/models/policy';
import { FormsModule } from '@angular/forms';
import { HermesClientService } from '../../hermes-client.service';
import { MatButtonModule } from '@angular/material/button';
import { MatDialog } from '@angular/material/dialog';
import { PolicyItemEditComponent } from '../policy-item-edit/policy-item-edit.component';
import { Group } from '../../shared/models/group';
import PolicyService from '../../shared/services/policy.service';

@Component({
  selector: 'policy-table',
  imports: [
    FormsModule,
    MatButtonModule,
    MatTableModule,
    MatIconModule,
  ],
  templateUrl: './policy-table.component.html',
  styleUrl: './policy-table.component.scss'
})
export class PolicyTableComponent implements OnInit, OnDestroy {
  private readonly client = inject(HermesClientService);
  private readonly policyService = inject(PolicyService);
  private readonly dialog = inject(MatDialog);

  policies = input.required<Policy[]>();
  groups = input.required<Group[]>();

  @ViewChild(MatTable) table: MatTable<Policy>;

  readonly displayedColumns = ['path', 'group', 'usage', 'span', 'actions'];
  private readonly _subscriptions: any[] = [];


  constructor() {
    this.table = {} as MatTable<Policy>;
  }

  ngOnInit(): void {
    this._subscriptions.push(this.policyService.create$?.subscribe(_ => this.table.renderRows()));
    this._subscriptions.push(this.policyService.update$?.subscribe(_ => this.table.renderRows()));
    this._subscriptions.push(this.policyService.delete$?.subscribe(_ => this.table.renderRows()));
  }

  ngOnDestroy(): void {
    this._subscriptions.filter(s => !!s).forEach(s => s.unsubscribe());
  }

  delete(policy: Policy) {
    this.client.deletePolicy(policy.id);
  }

  edit(policy: Policy) {
    this.dialog.open(PolicyItemEditComponent, {
      data: {
        policies: this.policies(),
        groups: this.groups(),
        policy_id: policy.id,
        group_id: policy.group_id,
        groupDisabled: true,
        isNew: false,
      }
    });
  }

  getGroupById(group_id: string) {
    return this.groups().find((g: Group) => g.id == group_id);
  }
}