import { HttpClient } from '@angular/common/http';
import { inject, Injectable } from '@angular/core';
import EventService from '../EventService';
import { environment } from '../../../../environments/environment';

@Injectable({
  providedIn: 'root'
})
export class ApiAuthenticationService {
  private readonly http = inject(HttpClient);
  private readonly events = inject(EventService);

  private authenticated: boolean;
  private user: any;
  private lastCheck: Date;

  constructor() {
    this.authenticated = false;
    this.user = null;
    this.lastCheck = new Date();
  }

  isAuthenticated() {
    return this.authenticated;
  }

  isAdmin() {
    return this.isAuthenticated() && this.user.role == 'ADMIN';
  }

  getImpersonatedId() {
    return this.user?.impersonation?.id;
  }

  getImpersonatedName() {
    return this.user?.impersonation?.name;
  }

  getUsername() {
    return this.user?.name;
  }

  logout() {
    this.updateAuthenticated(null, false, null);
  }

  update(jwt: string | null) {
    if (!jwt) {
      this.updateAuthenticated(null, false, null);
      return;
    }

    this.http.get(environment.API_HOST + '/auth/validate', {
      headers: {
        'Authorization': 'Bearer ' + jwt
      },
      withCredentials: true
    }).subscribe({
      next: (data: any) => this.updateAuthenticated(jwt, data?.authenticated, data?.user),
      error: () => this.updateAuthenticated(jwt, false, null)
    });
  }

  private updateAuthenticated(jwt: string | null, authenticated: boolean, user: any) {
    const previous = this.authenticated;
    this.user = user;
    this.authenticated = authenticated;
    this.lastCheck = new Date();

    if (jwt) {
      localStorage.setItem('jwt', jwt);
    } else {
      localStorage.removeItem('jwt');
    }

    if (previous != authenticated) {
      if (authenticated) {
        this.events.emit('login', null);
      } else {
        this.events.emit('logoff', null);
      }
    }
  }
}
